@@ -3,8 +3,8 @@ from .response_handler import ResponseHandler
 from .custom_views_operations import CustomViewsOperations, GetCustomViewsParam, GetCustomViewParam
 from .criteria import Criteria
 from .translation import Translation
+from .shared_details import SharedDetails
 from .response_wrapper import ResponseWrapper
 from .range import Range
-from .shared_to import SharedTo
 from .custom_view import CustomView
 from .info import Info
