@@ -44,7 +44,7 @@ class CustomViewsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/settings/custom_views'
+		api_path = api_path + '/crm/v2/settings/custom_views'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
@@ -75,7 +75,7 @@ class CustomViewsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/settings/custom_views/'
+		api_path = api_path + '/crm/v2/settings/custom_views/'
 		api_path = api_path + str(id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
