@@ -48,7 +48,7 @@ class Org(object):
 		The method to get the country
 
 		Returns:
-			string: A string value
+			string: A string representing the country
 		"""
 
 		return self.__country
@@ -72,7 +72,7 @@ class Org(object):
 		The method to get the photo_id
 
 		Returns:
-			string: A string value
+			string: A string representing the photo_id
 		"""
 
 		return self.__photo_id
@@ -96,7 +96,7 @@ class Org(object):
 		The method to get the city
 
 		Returns:
-			string: A string value
+			string: A string representing the city
 		"""
 
 		return self.__city
@@ -120,7 +120,7 @@ class Org(object):
 		The method to get the description
 
 		Returns:
-			string: A string value
+			string: A string representing the description
 		"""
 
 		return self.__description
@@ -144,7 +144,7 @@ class Org(object):
 		The method to get the mc_status
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the mc_status
 		"""
 
 		return self.__mc_status
@@ -168,7 +168,7 @@ class Org(object):
 		The method to get the gapps_enabled
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the gapps_enabled
 		"""
 
 		return self.__gapps_enabled
@@ -192,7 +192,7 @@ class Org(object):
 		The method to get the domain_name
 
 		Returns:
-			string: A string value
+			string: A string representing the domain_name
 		"""
 
 		return self.__domain_name
@@ -216,7 +216,7 @@ class Org(object):
 		The method to get the translation_enabled
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the translation_enabled
 		"""
 
 		return self.__translation_enabled
@@ -240,7 +240,7 @@ class Org(object):
 		The method to get the street
 
 		Returns:
-			string: A string value
+			string: A string representing the street
 		"""
 
 		return self.__street
@@ -264,7 +264,7 @@ class Org(object):
 		The method to get the alias
 
 		Returns:
-			string: A string value
+			string: A string representing the alias
 		"""
 
 		return self.__alias
@@ -288,7 +288,7 @@ class Org(object):
 		The method to get the currency
 
 		Returns:
-			string: A string value
+			string: A string representing the currency
 		"""
 
 		return self.__currency
@@ -312,7 +312,7 @@ class Org(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -336,7 +336,7 @@ class Org(object):
 		The method to get the state
 
 		Returns:
-			string: A string value
+			string: A string representing the state
 		"""
 
 		return self.__state
@@ -360,7 +360,7 @@ class Org(object):
 		The method to get the fax
 
 		Returns:
-			string: A string value
+			string: A string representing the fax
 		"""
 
 		return self.__fax
@@ -384,7 +384,7 @@ class Org(object):
 		The method to get the employee_count
 
 		Returns:
-			string: A string value
+			string: A string representing the employee_count
 		"""
 
 		return self.__employee_count
@@ -408,7 +408,7 @@ class Org(object):
 		The method to get the zip
 
 		Returns:
-			string: A string value
+			string: A string representing the zip
 		"""
 
 		return self.__zip
@@ -432,7 +432,7 @@ class Org(object):
 		The method to get the website
 
 		Returns:
-			string: A string value
+			string: A string representing the website
 		"""
 
 		return self.__website
@@ -456,7 +456,7 @@ class Org(object):
 		The method to get the currency_symbol
 
 		Returns:
-			string: A string value
+			string: A string representing the currency_symbol
 		"""
 
 		return self.__currency_symbol
@@ -480,7 +480,7 @@ class Org(object):
 		The method to get the mobile
 
 		Returns:
-			string: A string value
+			string: A string representing the mobile
 		"""
 
 		return self.__mobile
@@ -504,7 +504,7 @@ class Org(object):
 		The method to get the currency_locale
 
 		Returns:
-			string: A string value
+			string: A string representing the currency_locale
 		"""
 
 		return self.__currency_locale
@@ -528,7 +528,7 @@ class Org(object):
 		The method to get the primary_zuid
 
 		Returns:
-			string: A string value
+			string: A string representing the primary_zuid
 		"""
 
 		return self.__primary_zuid
@@ -552,7 +552,7 @@ class Org(object):
 		The method to get the zia_portal_id
 
 		Returns:
-			string: A string value
+			string: A string representing the zia_portal_id
 		"""
 
 		return self.__zia_portal_id
@@ -576,7 +576,7 @@ class Org(object):
 		The method to get the time_zone
 
 		Returns:
-			string: A string value
+			string: A string representing the time_zone
 		"""
 
 		return self.__time_zone
@@ -600,7 +600,7 @@ class Org(object):
 		The method to get the zgid
 
 		Returns:
-			string: A string value
+			string: A string representing the zgid
 		"""
 
 		return self.__zgid
@@ -624,7 +624,7 @@ class Org(object):
 		The method to get the country_code
 
 		Returns:
-			string: A string value
+			string: A string representing the country_code
 		"""
 
 		return self.__country_code
@@ -677,7 +677,7 @@ class Org(object):
 		The method to get the phone
 
 		Returns:
-			string: A string value
+			string: A string representing the phone
 		"""
 
 		return self.__phone
@@ -701,7 +701,7 @@ class Org(object):
 		The method to get the company_name
 
 		Returns:
-			string: A string value
+			string: A string representing the company_name
 		"""
 
 		return self.__company_name
@@ -725,7 +725,7 @@ class Org(object):
 		The method to get the privacy_settings
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the privacy_settings
 		"""
 
 		return self.__privacy_settings
@@ -749,7 +749,7 @@ class Org(object):
 		The method to get the primary_email
 
 		Returns:
-			string: A string value
+			string: A string representing the primary_email
 		"""
 
 		return self.__primary_email
@@ -773,7 +773,7 @@ class Org(object):
 		The method to get the iso_code
 
 		Returns:
-			string: A string value
+			string: A string representing the iso_code
 		"""
 
 		return self.__iso_code
@@ -800,7 +800,7 @@ class Org(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
