@@ -1,57 +1,48 @@
-from .image_upload import ImageUpload
+from .deleted_record import DeletedRecord
 from .criteria import Criteria
 from .file_details import FileDetails
-from .record_operations import RecordOperations, GetRecordParam, GetRecordHeader, DeleteRecordParam, GetRecordsParam, GetRecordsHeader, DeleteRecordsParam, GetDeletedRecordsParam, GetDeletedRecordsHeader, SearchRecordsParam, GetMassUpdateStatusParam, RecordCountParam
-from .count_wrapper import CountWrapper
-from .mass_update_response_wrapper import MassUpdateResponseWrapper
-from .recurring_activity import RecurringActivity
-from .record import Record
-from .options import Options
-from .download_handler import DownloadHandler
-from .info import Info
-from .convert_action_response import ConvertActionResponse
-from .convert_action_wrapper import ConvertActionWrapper
-from .body_wrapper import BodyWrapper
-from .tax import Tax
-from .consent import Consent
-from .lead_converter import LeadConverter
-from .convert_body_wrapper import ConvertBodyWrapper
-from .multi_select_lookup import MultiSelectLookup
-from .line_item_product import LineItemProduct
-from .field import Field
-from .count_handler import CountHandler
-from .mass_update_success_response import MassUpdateSuccessResponse
-from .convert_action_handler import ConvertActionHandler
-from .line_tax import LineTax
-from .widget import Widget
-from .deleted_record import DeletedRecord
 from .pricing_details import PricingDetails
+from .record_operations import RecordOperations, GetRecordParam, GetRecordHeader, UpdateRecordHeader, DeleteRecordParam, DeleteRecordHeader, GetRecordsParam, GetRecordsHeader, UpdateRecordsHeader, DeleteRecordsParam, DeleteRecordsHeader, UpsertRecordsHeader, GetDeletedRecordsParam, GetDeletedRecordsHeader, SearchRecordsParam, SearchRecordsHeader, GetMassUpdateStatusParam
 from .api_exception import APIException
 from .response_handler import ResponseHandler
 from .action_response import ActionResponse
+from .mass_update_response_wrapper import MassUpdateResponseWrapper
 from .success_response import SuccessResponse
 from .file_body_wrapper import FileBodyWrapper
+from .recurring_activity import RecurringActivity
+from .record import Record
 from .mass_update_response import MassUpdateResponse
+from .options import Options
 from .action_handler import ActionHandler
-from .price_book import PriceBook
+from .download_handler import DownloadHandler
+from .info import Info
 from .participants import Participants
+from .convert_action_response import ConvertActionResponse
 from .successful_convert import SuccessfulConvert
 from .action_wrapper import ActionWrapper
 from .mass_update_action_wrapper import MassUpdateActionWrapper
 from .reminder import Reminder
 from .mass_update_action_handler import MassUpdateActionHandler
 from .mass_update_body_wrapper import MassUpdateBodyWrapper
+from .convert_action_wrapper import ConvertActionWrapper
 from .deleted_records_wrapper import DeletedRecordsWrapper
+from .body_wrapper import BodyWrapper
+from .consent import Consent
 from .remind_at import RemindAt
 from .mass_update_action_response import MassUpdateActionResponse
 from .file_handler import FileHandler
+from .lead_converter import LeadConverter
+from .convert_body_wrapper import ConvertBodyWrapper
 from .deleted_records_handler import DeletedRecordsHandler
-from .mass_update_territory import MassUpdateTerritory
 from .mass_update_response_handler import MassUpdateResponseHandler
+from .inventory_line_items import InventoryLineItems
+from .line_item_product import LineItemProduct
+from .field import Field
 from .carry_over_tags import CarryOverTags
-from .multi_select_picklist import MultiSelectPicklist
 from .response_wrapper import ResponseWrapper
-from .wizard import Wizard
 from .comment import Comment
+from .mass_update_success_response import MassUpdateSuccessResponse
+from .convert_action_handler import ConvertActionHandler
 from .mass_update import MassUpdate
+from .line_tax import LineTax
 from .territory import Territory
